ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder { /* private fields */ }
Builder for Config.

Implementations

Source

impl ConfigBuilder

pub fn buffer_size(&mut self, value: Option<LogicalSize<u32>>) -> &mut Self

Sets the pixel dimensions of the buffer. The buffer will automatically stretch to fill the whole window. By default this will be the same as the window_size.

pub fn resizable(&mut self, value: bool) -> &mut Self

If this is true, the window created by mini_gl_fb will be set to resizable. This can be changed later. Please note that the buffer itself will not be automatically resized, only the viewport.

pub fn window_title(&mut self, value: String) -> &mut Self

The title of the window that will be created.

pub fn window_size(&mut self, value: LogicalSize<f64>) -> &mut Self

The logical size of the window that gets created. On HiDPI screens the actual size may be larger than this

pub fn invert_y(&mut self, value: bool) -> &mut Self

By default, the origin of the buffer is the bottom-left. This is known as “inverted Y”, as most screen-space coordinate systems begin from the top-left. By explicitly setting this option to false, you can switch to screen-space coordinates rather than OpenGL coordinates. Otherwise, you will have to invert all mouse events received from winit/glutin.

Source

impl ConfigBuilder

pub fn build(&self) -> Config

Builds a new Config.